---
title: <span class="badge builder"></span> TableBarGaugeCellOptions
---
# <span class="badge builder"></span> TableBarGaugeCellOptions

## Constructor

```python
TableBarGaugeCellOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.TableBarGaugeCellOptions
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: common.BarGaugeDisplayMode) -> typing.Self
```

### <span class="badge object-method"></span> value_display_mode

```python
def value_display_mode(value_display_mode: common.BarGaugeValueMode) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [TableBarGaugeCellOptions](./object-TableBarGaugeCellOptions.md)
